# Table of Contents

- [data-flow](<./data-flow.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Data Flow Diagrams](<./Data-Flow-Diagrams.md>)
  - [Creating Data Flow Diagrams](<./Data-Flow-Diagrams/Creating-Data-Flow-Diagrams.md>)
  - [Using Data Flow Diagrams](<./Data-Flow-Diagrams/Using-Data-Flow-Diagrams.md>)
  - [Adding Applications](<./Data-Flow-Diagrams/Adding-Applications.md>)
  - [Linking Diagrams to Other Diagrams in](<./Data-Flow-Diagrams/Linking-Diagrams-to-Other-Diagrams-in.md>)
  - [Expanding Interfaces](<./Data-Flow-Diagrams/Expanding-Interfaces.md>)
  - [Applying Labels](<./Data-Flow-Diagrams/Applying-Labels.md>)
  - [Drill-Down and Roll-Up Application](<./Data-Flow-Diagrams/Drill-Down-and-Roll-Up-Application.md>)
  - [Selecting Fact Sheets by Filter](<./Data-Flow-Diagrams/Selecting-Fact-Sheets-by-Filter.md>)
  - [Applying and Aggregating Views](<./Data-Flow-Diagrams/Applying-and-Aggregating-Views.md>)
  - [Updates from Inventory](<./Data-Flow-Diagrams/Updates-from-Inventory.md>)
  - [Was this page helpful?](<./Data-Flow-Diagrams/Was-this-page-helpful.md>)
